@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.26.3-Buenos Aires"
-#define _QGIS_VERSION "3.26.3-Buenos Aires"
+#define VERSION "3.34.1-Prizren"
+#define _QGIS_VERSION "3.34.1-Prizren"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3263
+//#define VERSION_INT 3341
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 32603
-#define _QGIS_VERSION_INT 32603
-#define ABISYM(x) x ## 32603
+#define VERSION_INT 33401
+#define _QGIS_VERSION_INT 33401
+#define ABISYM(x) x ## 33401
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Buenos Aires"
+#define RELEASE_NAME "Prizren"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,12 +31,12 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.26.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.34.1"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
 #if !defined(QSCINTILLA_VERSION_STR)
-#define QSCINTILLA_VERSION_STR "2.13.3"
+#define QSCINTILLA_VERSION_STR "2.14.1"
 #endif
 
 #if defined( __APPLE__ )
@@ -46,14 +46,14 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
-#define PYTHON_VERSION "3.10.8"
+#define PYTHON_VERSION "3.11.6"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "10"
-#define PYTHON_VERSION_PATCH "8"
+#define PYTHON_VERSION_MINOR "11"
+#define PYTHON_VERSION_PATCH "6"
 
 #define PROJ_VERSION_MAJOR 9
-#define PROJ_VERSION_MINOR 0
-#define PROJ_VERSION_PATCH 1
+#define PROJ_VERSION_MINOR 3
+#define PROJ_VERSION_PATCH 0
 
 /* #undef USING_NMAKE */
 
@@ -90,9 +90,13 @@
 
 /* #undef QGISDEBUG */
 
-/* #undef HAVE_QUICK */
+/* #undef AGGRESSIVE_SAFE_MODE */
 
-#define HAVE_QT5SERIALPORT
+#define HAVE_QUICK
+
+#define HAVE_QTSERIALPORT
+
+/* #undef HAVE_QTGAMEPAD */
 
 /* #undef HAVE_STATIC_PROVIDERS */
 
@@ -101,18 +105,20 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.4.3"
+#define PDAL_VERSION "2.6.1"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 4
+#define PDAL_VERSION_MINOR_INT 6
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "4"
-#define PDAL_VERSION_MICRO "3"
+#define PDAL_VERSION_MINOR "6"
+#define PDAL_VERSION_MICRO "1"
+
+#define HAVE_DRACO
 
 #define ENABLE_TESTS
 
-/* #undef HAS_KDE_QT5_PDF_TRANSFORM_FIX */
-/* #undef HAS_KDE_QT5_SMALL_CAPS_FIX */
-/* #undef HAS_KDE_QT5_FONT_STRETCH_FIX */
+#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
+#define HAS_KDE_QT5_SMALL_CAPS_FIX
+#define HAS_KDE_QT5_FONT_STRETCH_FIX
 
 #define HAVE_CRASH_HANDLER
 
